from .window import create_window
from .widgets import add_button, add_slider, add_text

__version__ = "1.0"

def create_djungarik_window(title="Djungarik", width=300, height=300):
    window = create_window(title, width, height)
    return window

__all__ = ['create_djungarik_window', 'add_button', 'add_slider', 'add_text']



import tkinter as tk

def add_button(window, text="Button", command=None):
    button = tk.Button(window, text=text, command=command)
    button.pack()
    return button

def add_slider(window, from_=0, to=100):
    slider = tk.Scale(window, from_=from_, to=to)
    slider.pack()
    return slider

def add_text(window, text="Hello!"):
    label = tk.Label(window, text=text)
    label.pack()
    return label



from setuptools import setup, find_packages

setup(
    name="djungarik",
    version="0.1.4a1",
    packages=find_packages(),
    author="djungar_DEV",
    author_email="arnispprt@gmail.com",
    description="Djungarik — A simple Tkinter-based UI package",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/djungarikDEV/djungarik",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)



import tkinter as tk

class DjungarikApp:
    def __init__(self, width=300, height=300, title="Djungarik"):
        self.window = tk.Tk()
        self.window.geometry(f"{width}x{height}")
        self.window.title(title)

        self.label = tk.Label(self.window, text="Welcome to Djungarik!", cursor="pointer")
        self.label.pack()

        self.button = tk.Button(self.window, text="Click Me", command=self.on_click, cursor="pointer")
        self.button.pack()

        self.slider = tk.Scale(self.window, from_=0, to=100, orient="horizontal")
        self.slider.pack()

        self.textbox = tk.Entry(self.window)
        self.textbox.pack()

    def on_click(self):
        print(f"Button clicked! Slider value: {self.slider.get()}, Text: {self.textbox.get()}")

    def run(self):
        self.window.mainloop()

def create_window(width=300, height=300, title="Djungarik"):
    app = DjungarikApp(width, height, title)
    app.run()



import tkinter as tk

def create_window(title="Djungarik Window", width=300, height=300):
    window = tk.Tk()
    window.title(title)
    window.geometry(f"{width}x{height}")

    label = tk.Label(window, text="Hello, Djungarik!", font=("Arial", 14))
    label.pack(pady=20)

    button = tk.Button(window, text="Click me!", command=lambda: print("Button clicked!"))
    button.pack(pady=10)

    slider = tk.Scale(window, from_=0, to=100, orient="horizontal")
    slider.pack(pady=10)

    window.mainloop()
